@@ -9,7 +9,7 @@ use URI::QueryParam qw//;
 use Carp qw//;
 use base qw/Class::Accessor/;
 
-our $VERSION = "0.2";
+our $VERSION = "0.3";
 
 # profiles currently supported by the W3C CSS Validator
 our %PROFILES = map { $_ => 1 } qw/none css1 css2 css21 css3 svg svgbasic
@@ -20,10 +20,10 @@ our %MEDIA    = map { $_ => 1 } qw/all aural braille embossed handheld
                                    print screen tty tv presentation/;
 
 # warnings level currently supported by the W3C CSS Validator
-our $WARNINGS = map { $_ => 1 } qw/0 1 2 no/;
+our %WARNINGS = map { $_ => 1 } qw/0 1 2 no/;
 
-__PACKAGE__->mk_accessors    qw/user_agent validator_uri/;
-__PACKAGE__->mk_ro_accessors qw/response request_uri som success/;
+__PACKAGE__->mk_accessors    (qw/user_agent validator_uri/);
+__PACKAGE__->mk_ro_accessors (qw/response request_uri som success/);
 
 sub new
 {
@@ -127,15 +127,9 @@ sub validate
     }
     
     if (defined $parm{warnings}) {
-        Carp::croak "warnings must be an integer 0 - 10\n"
-          unless $parm{warnings} =~ /^[0-9]|10$/;
-        
-        if ($parm{warnings} == 0) {
-            $uri->query_param(warning => "no");
-        }
-        else {
-            $uri->query_param(warning => $parm{warnings});
-        }
+        Carp::croak "warnings must be either \"no\" or an integer from 0 to 2\n"
+          unless $WARNINGS{$parm{warnings}};        
+        $uri->query_param(warning => $parm{warnings});
     }
     
     # request SOAP 1.2 output
@@ -292,14 +286,14 @@ had been specified.
 The CSS Version or profile to validate against, legal values are C<css1>, C<css2>, C<css21>,
 C<css3>, C<svg>, C<svgbasic>, C<svgtiny>, C<mobile>, C<atsc-tv>, and C<tv>. A special
 value C<none> can also be used. The default is C<undef> in which case the CSS Validator
-determines a default. This would currently behave as if C<css2> had been specified.
+determines a default.
 
 =item warnings => 2
 
-An integer C<0> - C<10> that determines how many warning messages you want to get
-back from the CSS Validator, C<0> means no warnings, C<10> would give most warnings,
-but is currently effectively the same as C<1>. The defaut is C<undef> in which case
-the CSS Validator determines a default value; this is expected to be as if C<2> had
+Either "no" or an integer C<0> - C<2> that determines how many warning messages you want to get
+back from the CSS Validator. "no" means no warning, C<0> means only the most serious warnings, 
+and C<2> will give all warnings, including low level ones. The defaut is C<undef> in which case
+the CSS Validator determines a default value; this is expected to be as if C<1> had
 been specified.
 
 =item language => "de"
@@ -348,10 +342,7 @@ Get the details of each warning with $val->warnings (see below).
 =item my @warnings = $val->warnings
 
 Returns a list with information about the warnings found for the
-style sheet. This is currently of limited use as it is broken, see
-L<http://www.w3.org/Bugs/Public/show_bug.cgi?id=771> for details.
-
-@@example
+style sheet. 
 
 =item my $ua = $val->user_agent
 
@@ -411,10 +402,9 @@ that the CSS Validator is a shared resource so do not abuse it: you should
 sleep between requests, and consider installing the Validator locally, see
 L<http://jigsaw.w3.org/css-validator/DOWNLOAD.html>.
 
-=head1 AUTHOR
+=head1 AUTHOR / COPYRIGHT / LICENSE
 
-Bjoern Hoehrmann <bjoern@hoehrmann.de>
-
-This module is licensed under the same terms as Perl itself.
+  Copyright 2004-2013 Bjoern Hoehrmann <bjoern@hoehrmann.de>.
+  This module is licensed under the same terms as Perl itself.
 
 =cut
